# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add qa fail templates

Revision ID: 2e079c8ac6e3
Revises: b45789abd24a
Create Date: 2021-10-28 10:00:16.586545

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "2e079c8ac6e3"
down_revision = "b45789abd24a"
branch_labels = None
depends_on = None

script_content = """#!/bin/sh

set -o errexit
export HOME=$TMPDIR

./conveyor --qa-fail $1

"""

condor = """executable = qa_fail.sh
arguments = metadata.json

output = qa_fail.out
error = qa_fail.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{script_content}' WHERE filename='qa_fail.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{condor}' WHERE filename='qa_fail.condor'
        """
    )


def downgrade():
    op.execute("DELETE FROM workflow_templates WHERE filename IN ('qa_fail.sh', 'qa_fail.condor')")
