"""workflows oracle update

Revision ID: 49b7c8150e72
Revises: 8aa23551a0fa
Create Date: 2023-11-22 14:26:55.355861

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '49b7c8150e72'
down_revision = '8aa23551a0fa'
branch_labels = None
depends_on = None


# Add instantclient_21_1 to the path to download ALMA data
old_curator_condor = """executable = curator.sh
arguments = metadata.json {{curator_type}}

output = curator.out
error = curator.err
log = condor.log

should_transfer_files = NO
+WantIOProxy = True
request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

new_curator_condor = """executable = curator.sh
arguments = metadata.json {{curator_type}}

output = curator.out
error = curator.err
log = condor.log

should_transfer_files = NO
+WantIOProxy = True
request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo ORACLE_HOME=/home/ssa/share/oracle/instantclient_21_1 LD_LIBRARY_PATH=/home/ssa/share/oracle/instantclient_21_1 PATH=/bin:/usr/bin:$(PATH)/home/ssa/share/oracle/instantclient_21_1"
requirements = HasLustre == True

queue

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{new_curator_condor}'
        WHERE filename='curator.condor'
        """
    )

    # Use instantclient_21_1 in the other templates
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content= regexp_replace(convert_from(content, 'utf-8'), E'instantclient_12_1', E'instantclient_21_1', 'g')::bytea
        WHERE filename='download.condor' OR filename='ingest_cal.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_curator_condor}'
        WHERE filename='curator.condor'
        """
    )

    op.execute(
        f"""
        UPDATE workflow_templates
        SET content= regexp_replace(convert_from(content, 'utf-8'), E'instantclient_21_1', E'instantclient_12_1', 'g')::bytea
        WHERE filename='download.condor' OR filename='ingest_cal.condor'
        """
    )
